#!/bin/sh
curpath=`pwd`
scriptpath=${0%/*}
arguments=$*
tmpfilepath=$scriptpath/tmp
ADBPATH=bin/adb

funcerr() {
  echo "設定に失敗しました. 以下の点を確認して再びこのスクリプトを実行してください."
  echo "1.Androidの設定より開発のUSBデバッグをONにしてください."
  echo "2.Androidで一度もFRepを起動していない場合は、いったんFRepを起動してください."
  echo "問題が解決しない場合は、下記サポートページ内FAQを参照してください."
  echo "http://strai.x0.com/frep-ja/faq#setup"
  cd $curpath
  exit 1
}

funcoffline() {
  echo "Android機器に表示されているUSBデバッグを許可してからEnterキーを押してください.(中止はCtrl+C)"
  read tmpinput
}

funcnumeric() {
  numcand=$1
  expr "$numcand" + 1 >/dev/null 2>&1
  # -lt 2 Numeric
  if [ $? -ge 2 ] ; then
    numcand=0
  fi
  echo $numcand
# return $numcand
}

funcdevice() {
  echo "複数のAndroid機器が接続されています."
  devnum=0
  $ADBPATH devices -l >$tmpfilepath
  # while~do~done with redirecting file because of variable lost.
  while read line ; do
    if [ -n "$line" ] ; then
      device="`echo $line | awk '{print $1}'`"
      if [ $devnum -gt 0 ] ; then
        echo "[$devnum] $line"
      fi
      devnum=`expr $devnum + 1`
    fi
  done <$tmpfilepath

  echo "設定する機器の番号を入力してください.(0でキャンセル)"
  read selnum
  seldevice=
  devnum=0
  selnum=`funcnumeric $selnum`

  if [ $selnum -eq 0 ] ; then
    echo "設定を中止しました."
    exit 0
  else
    # while~do~done with redirecting file because of variable lost.
    while read line ; do
    if [ -n "$line" ] ; then
      if [ $devnum -eq $selnum ] ; then
        seldevice="`echo $line | awk '{print $1}'`"
        break
      fi
      devnum=`expr $devnum + 1`
    fi
    done <$tmpfilepath
  fi
  rm $tmpfilepath

  if [ -n $seldevice ] ; then
    arguments="-s $seldevice"
    echo "[$selnum] $seldevice を選択しました."
  else
    echo "設定する機器1台のみ接続した状態で再度実行するか、あるいは設定する機器1台を"
    echo "オプション -s (上記シリアルの1つ) で指定してください."
    echo "例) linux_alt.sh -s 00000000"
    exit 1
  fi
}

# Return only first pid in ps result.
gettenth() {
  case $# in
    [0-9])
    return 0
    ;;
  esac
# shift to retrieve 10th arg
  shift
  echo $9
#  return $9
}

# Check pid and kill if already running.
killserv() {
  PS=`$ADBPATH $arguments shell ps strserv`
  PID=`gettenth $PS`
  case $PID in
    "");;
    0);;
    *)
    $ADBPATH $arguments shell kill $PID
    echo PID $PID strserv killed.
    ;;
  esac
# patch for Android 6
  PS=`$ADBPATH $arguments shell ps /data/local/tmp/strserv`
  PID=`gettenth $PS`
  case $PID in
    "");;
    0);;
    *)
    $ADBPATH $arguments shell kill $PID
    echo PID $PID strserv killed.
    ;;
  esac
  PS=`$ADBPATH $arguments shell ps /data/data/com.x0.strai.frep/app_bin/strserv`
  PID=`gettenth $PS`
  case $PID in
    "");;
    0);;
    *)
    $ADBPATH $arguments shell kill $PID
    echo PID $PID strserv killed.
    ;;
  esac
}

cd $scriptpath
chmod +x $ADBPATH
$ADBPATH devices > /dev/null 2>&1

# place binary and check USB debug connection
passed=0
while [ $passed -eq 0 ] ; do
  copied=`$ADBPATH $arguments shell "cat /data/data/com.x0.strai.frep/app_bin/strserv > /data/local/tmp/strserv" 2>&1`
  case $? in
    # passed (no error), start server
    0)
    passed=1
    $ADBPATH $arguments shell "chmod 777 /data/local/tmp/strserv"
    killserv
    echo "Server Startedと表示されたらCtrl+Cを押してスクリプトを抜けてください."
    echo "/data/local/tmp/strserv -c &" | $ADBPATH $arguments shell
    ;;
    *)
    # error
    case $copied in
      # error: more than one device/emulator (continue)
      *emulator)
      funcdevice
      ;;
      # error: device offline (continue)
      *offline)
      funcoffline
      ;;
      # error: device unauthorized (continue)
      *unauthorized*)
      funcoffline
      ;;
      # other error
      *)
      echo $pushed
      funcerr
      ;;
    esac
    ;;
  esac
done

cd $curpath
exit 0

